alpha phase is open, this means:
[lcr.git] / message.h
index fc00c02..cdc8163 100644 (file)
--- a/message.h
+++ b/message.h
@@ -120,7 +120,7 @@ enum { /* diversion types */
 enum { /* isdnsignal */
        mISDNSIGNAL_VOLUME,             /* change volume */
        mISDNSIGNAL_CONF,               /* joint/split conference */
-       mISDNSIGNAL_CALLDATA,           /* data required by call instance */
+       mISDNSIGNAL_JOINDATA,           /* data required by join instance */
        mISDNSIGNAL_ECHO,               /* enable/disable echoe */
        mISDNSIGNAL_DELAY,              /* use delay or adaptive jitter */
 };
@@ -154,7 +154,7 @@ struct connect_info {
        char extension[32];             /* internal id */
        char name[16];
        int isdn_port;                  /* internal/external port (if call is isdn) */
-       char interfaces[128];           /* interfaces for extenal calls */
+       char interface[128];            /* interface for extenal calls */
        int itype;                      /* type of interface */
        int ntype;                      /* type of number */
        int present;                    /* presentation */
@@ -261,7 +261,7 @@ struct param_mISDNsignal {
        int rxvol;
        int txvol;
        int conf;
-       int calldata;
+       int joindata;
        int tone;
        int echo;
        int delay;
@@ -287,7 +287,7 @@ union parameter {
        struct park_info parkinfo; /* MESSAGE_SUSPEND, MESSAGE_RESUME */
        int state; /* MESSAGE_TIMEOUT */
        int knock; /* MESSAGE_KNOCK 0=off !0=on */
-       int channel; /* MESSAGE_CHANNEL see RELATION_CHANNEL_* (call.h) */
+       int channel; /* MESSAGE_CHANNEL see RELATION_CHANNEL_* (join.h) */
        struct param_data data; /* MESSAGE_DATA */
        struct param_play play; /* MESSAGE_VBOX_PLAY */
        int speed; /* MESSAGE_VBOX_PLAY_SPEED */
@@ -299,8 +299,8 @@ union parameter {
 
 enum { /* message flow */
        PORT_TO_EPOINT,
-       EPOINT_TO_CALL,
-       CALL_TO_EPOINT,
+       EPOINT_TO_JOIN,
+       JOIN_TO_EPOINT,
        EPOINT_TO_PORT,
 };
 
@@ -311,6 +311,7 @@ struct message {
        int flow; /* from where to where */
        unsigned long id_from; /* in case of flow==PORT_TO_EPOINT: id_from is the port's serial, id_to is the epoint's serial */
        unsigned long id_to;
+       int keep;
        union parameter param;
 };
 
@@ -348,6 +349,7 @@ enum { /* messages between entities */
        MESSAGE_VBOX_TONE,      /* set answering VBOX tone */
        MESSAGE_TONE_COUNTER,   /* tone counter (for VBOX tone use) */
        MESSAGE_TONE_EOF,       /* tone is end of file */
+       MESSAGE_HELLO,          /* hello message for asterisk */
 };
 
 #define MESSAGES static const char *messages_txt[] = { \
@@ -379,11 +381,13 @@ enum { /* messages between entities */
        "MESSAGE_VBOX_TONE", \
        "MESSAGE_TONE_COUNTER", \
        "MESSAGE_TONE_EOF", \
+       "MESSAGE_HELLO", \
 };
 
 
 struct message *message_create(int id_from, int id_to, int flow, int type);
 void message_put(struct message *message);
+void message_forward(int id_from, int id_to, int flow, union parameter *param);
 struct message *message_get(void);
 void message_free(struct message *message);